==> eiciel-0.4.tar.bz2: eiciel-0.4/src/eiciel_bonobo.cpp <==
/*
   Component bonobo de Eiciel
   (C) Roger Ferrer Ibez - 2004

   $Revision: 1.1 $
*/
#include "config.hpp"
#include <string>
#include <gtkmm.h>
#include <libbonoboui.h>
#include "eiciel_main_controler.hpp"
#include "eiciel_main_window.hpp"
#include <iostream>
#include <libgnomevfs/gnome-vfs.h>

// -- Debug
#include <exception>
#include <stdexcept>
#include <signal.h>

#include <gettext.h>

#define OAFIID_EICIEL "OAFIID:Eiciel_Component"
#define OAFIID_EICIEL_FABRICA "OAFIID:Eiciel_Component_Fabrica"
#define PROPERTY_URIS 1
#define PROPERTY_OPENFILE 2
#define PROPERTY_ERRORMESSAGE 3

static void get_prop (BonoboPropertyBag *bag,
        BonoboArg *arg,
        guint arg_id,
        CORBA_Environment *ev,
        gpointer user_data)
{
	if (arg_id == PROPERTY_OPENFILE)
	{
		EicielWindow* p = (EicielWindow*) user_data;
		BONOBO_ARG_SET_BOOLEAN (arg, p->fitxerObert());
	}
	else if (arg_id == PROPERTY_ERRORMESSAGE)
	{
		EicielWindow* p = (EicielWindow*) user_data;
		BONOBO_ARG_SET_STRING(arg, p->ultimError().c_str());
	}
}

static void set_prop (BonoboPropertyBag *bag,
        const BonoboArg *arg,
        guint arg_id,
        CORBA_Environment *ev,
        gpointer user_data)
{
    if (arg_id == PROPERTY_URIS) {
        CORBA_sequence_CORBA_string* uris;

        uris = (CORBA_sequence_CORBA_string*) arg->_value;

        EicielWindow* p = (EicielWindow*)user_data;

        char* local = gnome_vfs_get_local_path_from_uri (uris->_buffer[0]);
        std::string s(local);
        free(local);
        
        p->inicialitzar(s);
    }
}

static void senyal_set_frame(BonoboControl*, EicielWindow* e)
{
	if (e->get_parent() != NULL)
	{
		// Construcci
	}
	else
	{
		// Destrucci v_v
		delete e;
	}
}

static BonoboObject* control_factory (BonoboGenericFactory *instance,
				      const char           *req_iid,
				      void                 *data)
{
    if (req_iid == NULL)
    {
        return NULL;
    }

    static const std::string iid = OAFIID_EICIEL;

    if (req_iid != iid)
    {
        return NULL;
    }


    // Aix s l'unic que farem amb C++, la resta es pot fer amb
    // C :)
    EicielMainControler* eiciel_controller = new EicielMainControler();
    Gtk::Widget* widget;
    EicielWindow* eiciel = Gtk::manage(new EicielWindow(eiciel_controller));
    widget = eiciel;


    BonoboPropertyBag* prop_bag = bonobo_property_bag_new (get_prop, set_prop, widget);

    BonoboControl* control = bonobo_control_new(widget->gobj());

	g_signal_connect(control, "set-frame", G_CALLBACK(senyal_set_frame), eiciel);

    bonobo_control_set_properties (control, BONOBO_OBJREF(prop_bag), NULL);

	bonobo_property_bag_add (prop_bag, "uris", PROPERTY_URIS, 
			TC_CORBA_sequence_CORBA_string,	 NULL, "URI of selected file", 0);

	bonobo_property_bag_add(prop_bag, "fitxerobert", PROPERTY_OPENFILE,
			BONOBO_ARG_BOOLEAN, NULL, "Indica si el fitxer est obert", 0);

	bonobo_property_bag_add(prop_bag, "missatgeerror", PROPERTY_ERRORMESSAGE,
			BONOBO_ARG_STRING, NULL, "Retorna l'ultim missatge d'error", 0);

    // Diu un exemple que ja no ens cal la referncia :-?
    bonobo_object_unref(BONOBO_OBJECT(prop_bag)); 

	bonobo_control_life_instrument (control);

    return BONOBO_OBJECT(control);
}

int main(int argc, char* argv[])
{
     std::set_terminate(__gnu_cxx::__verbose_terminate_handler);
#ifdef ENABLE_NLS
    setlocale(LC_ALL, "");
    bindtextdomain("eiciel-bonobo", DATADIR "/locale");
    textdomain("eiciel-bonobo");

    // Volem les traduccions en UTF-8 (independentment del
    // format usat per a traduir)
    bind_textdomain_codeset ("eiciel-bonobo", "UTF-8");
#endif

    if (!bonobo_ui_init("bonobo-nautilus-eiciel", "1.0", &argc, argv))
    {
        g_error(_("Cannot start libbonoboui. Aborting"));
        return 1;
    }

    Gtk::Main main(argc, argv);	

    return bonobo_generic_factory_main (OAFIID_EICIEL_FABRICA,
            control_factory, 0); 
}

==> eiciel-0.4.1.tar.bz2: eiciel-0.4.1/src/eiciel_bonobo.cpp <==
/*
   Component bonobo de Eiciel
   (C) Roger Ferrer Ibez - 2004

   $Revision: 1.2 $
*/
#include "config.hpp"
#include <string>
#include <gtkmm.h>
#include <libbonoboui.h>
#include "eiciel_main_controler.hpp"
#include "eiciel_main_window.hpp"
#include <iostream>
#include <libgnomevfs/gnome-vfs.h>

// -- Debug
#include <exception>
#include <stdexcept>
#include <signal.h>

#include <gettext.h>

#define OAFIID_EICIEL "OAFIID:Eiciel_Component"
#define OAFIID_EICIEL_FABRICA "OAFIID:Eiciel_Component_Fabrica"
#define PROPERTY_URIS 1
#define PROPERTY_OPENFILE 2
#define PROPERTY_ERRORMESSAGE 3

static void get_prop (BonoboPropertyBag *bag,
        BonoboArg *arg,
        guint arg_id,
        CORBA_Environment *ev,
        gpointer user_data)
{
	if (arg_id == PROPERTY_OPENFILE)
	{
		EicielWindow* p = (EicielWindow*) user_data;
		BONOBO_ARG_SET_BOOLEAN (arg, p->fitxerObert());
	}
	else if (arg_id == PROPERTY_ERRORMESSAGE)
	{
		EicielWindow* p = (EicielWindow*) user_data;
		BONOBO_ARG_SET_STRING(arg, p->ultimError().c_str());
	}
}

static void set_prop (BonoboPropertyBag *bag,
        const BonoboArg *arg,
        guint arg_id,
        CORBA_Environment *ev,
        gpointer user_data)
{
    if (arg_id == PROPERTY_URIS) {
        CORBA_sequence_CORBA_string* uris;

        uris = (CORBA_sequence_CORBA_string*) arg->_value;

        EicielWindow* p = (EicielWindow*)user_data;

        char* local = gnome_vfs_get_local_path_from_uri (uris->_buffer[0]);
        std::string s(local);
        free(local);
        
        p->inicialitzar(s);
    }
}

static void senyal_set_frame(BonoboControl*, EicielWindow* e)
{
	if (e->get_parent() != NULL)
	{
		// Construcci
	}
	else
	{
		// Destrucci v_v
		delete e;
	}
}

static BonoboObject* control_factory (BonoboGenericFactory *instance,
				      const char           *req_iid,
				      void                 *data)
{
    if (req_iid == NULL)
    {
        return NULL;
    }

    static const std::string iid = OAFIID_EICIEL;

    if (req_iid != iid)
    {
        return NULL;
    }


    // Aix s l'unic que farem amb C++, la resta es pot fer amb
    // C :)
    EicielMainControler* eiciel_controller = new EicielMainControler();
    Gtk::Widget* widget;
    EicielWindow* eiciel = Gtk::manage(new EicielWindow(eiciel_controller));
    widget = eiciel;


    BonoboPropertyBag* prop_bag = bonobo_property_bag_new (get_prop, set_prop, widget);

    BonoboControl* control = bonobo_control_new(widget->gobj());

	g_signal_connect(control, "set-frame", G_CALLBACK(senyal_set_frame), eiciel);

    bonobo_control_set_properties (control, BONOBO_OBJREF(prop_bag), NULL);

	bonobo_property_bag_add (prop_bag, "uris", PROPERTY_URIS, 
			TC_CORBA_sequence_CORBA_string,	 NULL, "URI of selected file", 0);

	bonobo_property_bag_add(prop_bag, "fitxerobert", PROPERTY_OPENFILE,
			BONOBO_ARG_BOOLEAN, NULL, "Indica si el fitxer est obert", 0);

	bonobo_property_bag_add(prop_bag, "missatgeerror", PROPERTY_ERRORMESSAGE,
			BONOBO_ARG_STRING, NULL, "Retorna l'ultim missatge d'error", 0);

    // Diu un exemple que ja no ens cal la referncia :-?
    bonobo_object_unref(BONOBO_OBJECT(prop_bag)); 

	bonobo_control_life_instrument (control);

    return BONOBO_OBJECT(control);
}

int main(int argc, char* argv[])
{
     std::set_terminate(__gnu_cxx::__verbose_terminate_handler);
#ifdef ENABLE_NLS
    setlocale(LC_ALL, "");
    bindtextdomain("eiciel", DATADIR "/locale");
    textdomain("eiciel");

    // Volem les traduccions en UTF-8 (independentment del
    // format usat per a traduir)
    bind_textdomain_codeset ("eiciel", "UTF-8");
#endif

    if (!bonobo_ui_init("bonobo-nautilus-eiciel", "1.0", &argc, argv))
    {
        g_error(_("Cannot start libbonoboui. Aborting"));
        return 1;
    }

    Gtk::Main main(argc, argv);	

    return bonobo_generic_factory_main (OAFIID_EICIEL_FABRICA,
            control_factory, 0); 
}
